<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>Mou a la paperera</translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Treu de l&apos;acoblador</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Acobla</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Força&apos;n la sortida</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tanca-ho tot</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Treu de l&apos;acoblador</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Afegeix a l&apos;acoblador</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Força&apos;n la sortida</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tanca-ho tot</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation>%1 fitxers</translation>
    </message>
</context>
</TS>